@@ -43,6 +43,14 @@ fi
 	echo "(or a newer version if it is available)"
 	DIE=1
 }
+
+(intltoolize --version) < /dev/null > /dev/null 2>&1 || {
+	echo
+	echo "You must have intltool installed to compile gtk-engines."
+	DIE=1
+}
+                        
+
 if test "$DIE" -eq 1; then
 	exit 1
 fi
@@ -53,10 +61,13 @@ if test -z "$*"; then
 fi
 
 libtoolize --force --copy
+intltoolize --force --copy --automake
+
 
 $ACLOCAL $ACLOCAL_FLAGS
 autoconf
 $AUTOMAKE --add-missing
+autoheader
 cd $THEDIR
 
 $srcdir/configure --enable-maintainer-mode "$@"
