@@ -16,7 +16,6 @@ typedef enum
 	CL_NUM_STYLES = 4
 } ClearlooksStyles;
 
-
 typedef enum
 {
 	CL_STATE_NORMAL,
@@ -95,14 +94,17 @@ typedef enum
 typedef enum
 {
 	CL_FOCUS_BUTTON,
+	CL_FOCUS_BUTTON_FLAT,
 	CL_FOCUS_LABEL,
+	CL_FOCUS_TREEVIEW,
 	CL_FOCUS_TREEVIEW_HEADER,
 	CL_FOCUS_TREEVIEW_ROW,
 	CL_FOCUS_TREEVIEW_DND,
 	CL_FOCUS_SCALE,
 	CL_FOCUS_TAB,
 	CL_FOCUS_COLOR_WHEEL_DARK,
-	CL_FOCUS_COLOR_WHEEL_LIGHT
+	CL_FOCUS_COLOR_WHEEL_LIGHT,
+	CL_FOCUS_UNKNOWN
 } ClearlooksFocusType;
 
 
@@ -273,6 +275,7 @@ typedef struct
 	CairoColor          color;
 	boolean             has_color;
 	gint                line_width;
+	gint                padding;
 	guint8*             dash_list;
 	boolean             interior;
 } FocusParameters;
