@@ -4,7 +4,7 @@
 typedef struct _MistStyle MistStyle;
 typedef struct _MistStyleClass MistStyleClass;
 
-extern GType mist_type_style;
+GE_INTERNAL extern GType mist_type_style;
 
 #define MIST_TYPE_STYLE              mist_type_style
 #define MIST_STYLE(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), MIST_TYPE_STYLE, MistStyle))
@@ -25,6 +25,5 @@ struct _MistStyleClass
   GtkStyleClass parent_class;
 };
 
-void mist_style_register_type (GTypeModule *module);
-
+GE_INTERNAL void mist_style_register_type (GTypeModule *module);
 
